@@ -1,11 +1,13 @@
 import sys
 import time
+import curlify
 from datetime import datetime
 from datetime import timedelta
 
 import inforion.ionapi.model.inforlogin as inforlogin
 from inforion.ionapi.controller import *
 from inforion.ionapi.model import *
+from inforion.logger.logger import get_logger
 
 # from io import BytesIO
 # import gzip
@@ -20,6 +22,8 @@ import inforion.ionapi.model.inforlogin as inforlogin
 
 # import inforion.ionapi.basic as inforlogin
 
+logger = get_logger("main", True)
+
 
 class TimeoutHTTPAdapter(HTTPAdapter):
     def __init__(self, *args, **kwargs):
@@ -71,7 +75,7 @@ def sendresults(url, _headers, data, timeout=65, stream=False):
     if datetime.now() > inforlogin._GLOBAL_session_expire:
 
         headers = inforlogin.reconnect()
-        logging.info(
+        logger.info(
             " Reconnect and Next Reconnect will be "
             + str(inforlogin._GLOBAL_session_expire)
         )
@@ -87,33 +91,31 @@ def sendresults(url, _headers, data, timeout=65, stream=False):
                 timeout=timeout,
                 stream=stream,
             )
-
+            logger.debug("Sending request: " + curlify.to_curl(response.request))
+            # logger.debug("Response received: " + response.content)
             if response.status_code == 200:
                 try:
                     r = response.json()
+                    logger.debug("Response received: " + json.dumps(r))
                     break
-
                 except ValueError:
-                    logging.error(r)
                     r = "JSON Error"
-
-                    print(r)
+                    logger.error(r)
             else:
-
                 if z < 5:
-                    logging.info(" Error try to get new session " + str(z) + "/5")
+                    logger.info(" Error try to get new session " + str(z) + "/5")
                     headers = inforlogin.reconnect()
                     time.sleep(10)
                 elif z == 5:
                     sys.exit(0)
 
     except requests.exceptions.TooManyRedirects:
-        logging.error("Too many redirects")
+        logger.error("Too many redirects")
         r = "Error - Too many redirects"
         raise SystemExit(e)
     except requests.exceptions.RequestException as e:
         # catastrophic error. bail.
-        logging.error("OOps: Something Else", e)
+        logger.error("OOps: Something Else", e)
         raise SystemExit(e)
         r = "Error"
 
